pub struct SyscallAbort {}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Abort syscall functions, called when the SBF program calls abort()
LLVM will insert calls to abort() if it detects an untenable situation,
abort() is not intended to be called explicitly by the program.
Causes the SBF program to be halted immediately
Implementations
Sourceimpl SyscallAbort
impl SyscallAbort
Sourcepub fn rust(
_invoke_context: &mut InvokeContext<'_, '_>,
_arg1: u64,
_arg2: u64,
_arg3: u64,
_arg4: u64,
_arg5: u64,
_memory_mapping: &mut MemoryMapping<'_>,
) -> Result<u64, Box<dyn Error>>
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn rust( _invoke_context: &mut InvokeContext<'_, '_>, _arg1: u64, _arg2: u64, _arg3: u64, _arg4: u64, _arg5: u64, _memory_mapping: &mut MemoryMapping<'_>, ) -> Result<u64, Box<dyn Error>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Rust interface
Sourcepub fn vm(
_invoke_context: *mut EbpfVm<'_, InvokeContext<'_, '_>>,
_arg1: u64,
_arg2: u64,
_arg3: u64,
_arg4: u64,
_arg5: u64,
)
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn vm( _invoke_context: *mut EbpfVm<'_, InvokeContext<'_, '_>>, _arg1: u64, _arg2: u64, _arg3: u64, _arg4: u64, _arg5: u64, )
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
VM interface