pub struct SyscallInvokeSignedRust {}๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
Cross-program invocation called from Rust
Implementations
Sourceimpl SyscallInvokeSignedRust
impl SyscallInvokeSignedRust
Sourcepub fn rust(
invoke_context: &mut InvokeContext<'_, '_>,
instruction_addr: u64,
account_infos_addr: u64,
account_infos_len: u64,
signers_seeds_addr: u64,
signers_seeds_len: u64,
memory_mapping: &mut MemoryMapping<'_>,
) -> Result<u64, Box<dyn Error>>
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn rust( invoke_context: &mut InvokeContext<'_, '_>, instruction_addr: u64, account_infos_addr: u64, account_infos_len: u64, signers_seeds_addr: u64, signers_seeds_len: u64, memory_mapping: &mut MemoryMapping<'_>, ) -> Result<u64, Box<dyn Error>>
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Rust interface
Sourcepub fn vm(
invoke_context: *mut EbpfVm<'_, InvokeContext<'_, '_>>,
instruction_addr: u64,
account_infos_addr: u64,
account_infos_len: u64,
signers_seeds_addr: u64,
signers_seeds_len: u64,
)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn vm( invoke_context: *mut EbpfVm<'_, InvokeContext<'_, '_>>, instruction_addr: u64, account_infos_addr: u64, account_infos_len: u64, signers_seeds_addr: u64, signers_seeds_len: u64, )
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.VM interface